Examples — csdmpy 0.1.1 documentation

# Examples

In this section, we present illustrative examples for importing files serialized with CSD model using csdmpy package. Because CSD model allows multi-dimensional datasets with multiple dependent variables, we use a shorthand notation of \(d\mathrm{D}\{p\}\) to indicate that a dataset has \(p\)-component dependent variable defined on a \(d\)-dimensional coordinate grid. In the case of correlated datasets, the number of components in each dependent variable is given as a list within the curly braces, i.e., \(d\mathrm{D}\{p_0, p_1, p_2, ...\}\).

For the following examples, you can download the corresponding files here.

Example Dataset

- Scalar, 1D{1} datasets
  - Global Mean Sea Level rise dataset
  - Nuclear Magnetic Resonance (MNR) dataset
  - Electron Paramagnetic Resonance (EPR) dataset
  - Gas Chromatography dataset
  - Fourier Transform Infrared Spectroscopy (FTIR) dataset
  - Ultraviolet–visible (UV-vis) dataset
  - Mass spectrometry dataset
- Scalar, 2D{1} datasets
  - Astronomy dataset
  - Nuclear Magnetic Resonance (NMR) dataset
  - Transmission Electron Microscopy (TEM) dataset
- Vector, 2D{2} datasets
  - Vector dataset
- Pixel, 2D{3} datasets
  - Image datasets
- Correlated Dataset
  - Meteorological, 2D{1,1,2,1,1} dataset
  - Astronomy, 2D{1,1,1} dataset (Creating image composition)
    - Image composition
- Labeled Dataset